# dsa_stl
- ##### python package for Data Structure and Algorithms.
---
## Installation
```
pip install dsa_stl
```
---
## Testing

```
from dsa_stl import testdsa
testdsa.test()
```
##### Output

`
test successful...
`
---
## Available Libraries
- <a href="https://github.com/aman2000jaiswal14/dsa_stl/blob/main/Documentation/doc_graph_stl.md" > graph_stl </a>
- <a href="https://github.com/aman2000jaiswal14/dsa_stl/blob/main/Documentation/doc_directed_graph_stl.md" > directed_graph_stl </a>
- <a href="https://github.com/aman2000jaiswal14/dsa_stl/blob/main/Documentation/doc_dsu_stl.md" > dsu_stl </a>
- <a href="https://github.com/aman2000jaiswal14/dsa_stl/blob/main/Documentation/doc_lca_stl.md" > lca_graph_stl </a>
- <a href="https://github.com/aman2000jaiswal14/dsa_stl/blob/main/Documentation/doc_Balance_bst.md" > Balance_bst </a>

## Git Hub
- <a href = "https://github.com/aman2000jaiswal14/dsa_stl"> Git Hub Code </a>